summaryrefslogtreecommitdiffstats
path: root/tdegtk
diff options
context:
space:
mode:
Diffstat (limited to 'tdegtk')
-rw-r--r--tdegtk/tdegtk-theme.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/tdegtk/tdegtk-theme.cpp b/tdegtk/tdegtk-theme.cpp
index cf32be6..e7e4af7 100644
--- a/tdegtk/tdegtk-theme.cpp
+++ b/tdegtk/tdegtk-theme.cpp
@@ -112,11 +112,11 @@ G_MODULE_EXPORT GtkThemingEngine* create_engine(void) {
gtk3TQtEnable = true;
gtk3TQtDebug = (getenv("GTK3_TQT_ENGINE_DEBUG") != NULL) ? 1 : 0;
- DEBUG_PRINT("Creating KApplication")
+ DEBUG_PRINT("Creating TDEApplication")
int argc = 1;
char** argv;
// Supply it with fake data to keep KApplication happy
argv = (char**) malloc(sizeof(char*));
argv[0] = (char*) malloc(sizeof(char) * 21);
strncpy(argv[0], "gtk3-tqt-application", 21);
@@ -127,8 +127,8 @@ G_MODULE_EXPORT GtkThemingEngine* create_engine(void) {
"", 0 /* TODO: Website */, "kb9vqf@pearsoncomputing.net");
TDECmdLineArgs::init(argc, const_cast<char**>(argv), &aboutData);
- KApplication::disableAutoDcopRegistration();
- new KApplication(gdk_x11_get_default_xdisplay(), true, 0, 0, true);
+ TDEApplication::disableAutoDcopRegistration();
+ new TDEApplication(gdk_x11_get_default_xdisplay(), true, 0, 0, true);
// Propagate glib events to GTK as needed
if (tqApp) {
@@ -112,11 +112,11 @@ G_MODULE_EXPORT GtkThemingEngine* create_engine(void) {
int argc = 1;
char** argv;
- // Supply it with fake data to keep KApplication happy
+ // Supply it with fake data to keep TDEApplication happy
argv = (char**) malloc(sizeof(char*));
argv[0] = (char*) malloc(sizeof(char) * 21);